@@ -28,8 +28,10 @@ from .qrcodegenerator import QRCodeGenerator
 from .coupletgenerator import CoupletGenerator
 from .artsigngenerator import ArtSignGenerator
 from .controlpcbyemail import ControlPCbyEmail
+from .modifyfoldericon import ModifyFolderICON
 from .naughtyconfession import NaughtyConfession
 from .goodgoodgenerator import GoodGoodGenerator
+from .githubacceleration import GithubAcceleration
 from .luxunsentencesquery import LuxunSentencesQuery
 from .hubbleseeonbirthday import HubbleSeeOnBirthday
 from .newyearcardgenerator import NewYearCardGenerator
